@@ -15,6 +15,7 @@ mod dele;
 mod feat;
 mod help;
 mod list;
+mod md5;
 mod mdtm;
 mod mkd;
 mod mode;
@@ -53,6 +54,7 @@ pub use dele::Dele;
 pub use feat::Feat;
 pub use help::Help;
 pub use list::List;
+pub use md5::Md5;
 pub use mdtm::Mdtm;
 pub use mkd::Mkd;
 pub use mode::{Mode, ModeParam};
